/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM e:/builds/tinderbox/XR-Trunk/WINNT_5.2_Depend/mozilla/dom/public/idl/xul/nsIDOMXULContainerElement.idl
 */

#ifndef __gen_nsIDOMXULContainerElement_h__
#define __gen_nsIDOMXULContainerElement_h__


#ifndef __gen_nsIDOMXULElement_h__
#include "nsIDOMXULElement.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMXULContainerElement */
#define NS_IDOMXULCONTAINERELEMENT_IID_STR "edfeaf37-3b24-4466-af7a-b3851044f1c1"

#define NS_IDOMXULCONTAINERELEMENT_IID \
  {0xedfeaf37, 0x3b24, 0x4466, \
    { 0xaf, 0x7a, 0xb3, 0x85, 0x10, 0x44, 0xf1, 0xc1 }}

class NS_NO_VTABLE nsIDOMXULContainerElement : public nsIDOMXULElement {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDOMXULCONTAINERELEMENT_IID)

  /**
   * Creates an item for the given label and value and appends it to the
   * container.
   *
   * @param aLabel - the label for the new item
   * @param aValue - the value of the new item
   */
  /* nsIDOMXULElement appendItem (in DOMString aLabel, in DOMString aValue); */
  NS_IMETHOD AppendItem(const nsAString & aLabel, const nsAString & aValue, nsIDOMXULElement **_retval) = 0;

  /**
   * Creates an item for the given label and value and inserts it into the
   * container at the specified position.
   *
   * @param aIndex - the index where the new item will be inserted
   * @param aLabel - the label for the new item
   * @param aValue - the value of the new item
   */
  /* nsIDOMXULElement insertItemAt (in long aIndex, in DOMString aLabel, in DOMString aValue); */
  NS_IMETHOD InsertItemAt(PRInt32 aIndex, const nsAString & aLabel, const nsAString & aValue, nsIDOMXULElement **_retval) = 0;

  /**
   * Removes an item from the container.
   *
   * @param aIndex - index of the item to remove
   */
  /* nsIDOMXULElement removeItemAt (in long aIndex); */
  NS_IMETHOD RemoveItemAt(PRInt32 aIndex, nsIDOMXULElement **_retval) = 0;

  /**
   * Returns a count of items in the container.
   */
  /* readonly attribute unsigned long itemCount; */
  NS_IMETHOD GetItemCount(PRUint32 *aItemCount) = 0;

  /**
   * Returns the index of an item or -1 if the item is not in the container.
   *
   * @param aItem - the item to determine the index of
   */
  /* long getIndexOfItem (in nsIDOMXULElement aItem); */
  NS_IMETHOD GetIndexOfItem(nsIDOMXULElement *aItem, PRInt32 *_retval) = 0;

  /**
   * Returns the item at a given index or null if the item is not is the
   * container.
   *
   * @param aIndex - the index of the item to return
   */
  /* nsIDOMXULElement getItemAtIndex (in long aIndex); */
  NS_IMETHOD GetItemAtIndex(PRInt32 aIndex, nsIDOMXULElement **_retval) = 0;

  /**
   * Returns the parent container if any.
   */
  /* readonly attribute nsIDOMXULElement parentContainer; */
  NS_IMETHOD GetParentContainer(nsIDOMXULElement * *aParentContainer) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDOMXULContainerElement, NS_IDOMXULCONTAINERELEMENT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMXULCONTAINERELEMENT \
  NS_IMETHOD AppendItem(const nsAString & aLabel, const nsAString & aValue, nsIDOMXULElement **_retval); \
  NS_IMETHOD InsertItemAt(PRInt32 aIndex, const nsAString & aLabel, const nsAString & aValue, nsIDOMXULElement **_retval); \
  NS_IMETHOD RemoveItemAt(PRInt32 aIndex, nsIDOMXULElement **_retval); \
  NS_IMETHOD GetItemCount(PRUint32 *aItemCount); \
  NS_IMETHOD GetIndexOfItem(nsIDOMXULElement *aItem, PRInt32 *_retval); \
  NS_IMETHOD GetItemAtIndex(PRInt32 aIndex, nsIDOMXULElement **_retval); \
  NS_IMETHOD GetParentContainer(nsIDOMXULElement * *aParentContainer); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMXULCONTAINERELEMENT(_to) \
  NS_IMETHOD AppendItem(const nsAString & aLabel, const nsAString & aValue, nsIDOMXULElement **_retval) { return _to AppendItem(aLabel, aValue, _retval); } \
  NS_IMETHOD InsertItemAt(PRInt32 aIndex, const nsAString & aLabel, const nsAString & aValue, nsIDOMXULElement **_retval) { return _to InsertItemAt(aIndex, aLabel, aValue, _retval); } \
  NS_IMETHOD RemoveItemAt(PRInt32 aIndex, nsIDOMXULElement **_retval) { return _to RemoveItemAt(aIndex, _retval); } \
  NS_IMETHOD GetItemCount(PRUint32 *aItemCount) { return _to GetItemCount(aItemCount); } \
  NS_IMETHOD GetIndexOfItem(nsIDOMXULElement *aItem, PRInt32 *_retval) { return _to GetIndexOfItem(aItem, _retval); } \
  NS_IMETHOD GetItemAtIndex(PRInt32 aIndex, nsIDOMXULElement **_retval) { return _to GetItemAtIndex(aIndex, _retval); } \
  NS_IMETHOD GetParentContainer(nsIDOMXULElement * *aParentContainer) { return _to GetParentContainer(aParentContainer); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMXULCONTAINERELEMENT(_to) \
  NS_IMETHOD AppendItem(const nsAString & aLabel, const nsAString & aValue, nsIDOMXULElement **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->AppendItem(aLabel, aValue, _retval); } \
  NS_IMETHOD InsertItemAt(PRInt32 aIndex, const nsAString & aLabel, const nsAString & aValue, nsIDOMXULElement **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->InsertItemAt(aIndex, aLabel, aValue, _retval); } \
  NS_IMETHOD RemoveItemAt(PRInt32 aIndex, nsIDOMXULElement **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveItemAt(aIndex, _retval); } \
  NS_IMETHOD GetItemCount(PRUint32 *aItemCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetItemCount(aItemCount); } \
  NS_IMETHOD GetIndexOfItem(nsIDOMXULElement *aItem, PRInt32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIndexOfItem(aItem, _retval); } \
  NS_IMETHOD GetItemAtIndex(PRInt32 aIndex, nsIDOMXULElement **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetItemAtIndex(aIndex, _retval); } \
  NS_IMETHOD GetParentContainer(nsIDOMXULElement * *aParentContainer) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetParentContainer(aParentContainer); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMXULContainerElement : public nsIDOMXULContainerElement
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMXULCONTAINERELEMENT

  nsDOMXULContainerElement();

private:
  ~nsDOMXULContainerElement();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMXULContainerElement, nsIDOMXULContainerElement)

nsDOMXULContainerElement::nsDOMXULContainerElement()
{
  /* member initializers and constructor code */
}

nsDOMXULContainerElement::~nsDOMXULContainerElement()
{
  /* destructor code */
}

/* nsIDOMXULElement appendItem (in DOMString aLabel, in DOMString aValue); */
NS_IMETHODIMP nsDOMXULContainerElement::AppendItem(const nsAString & aLabel, const nsAString & aValue, nsIDOMXULElement **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIDOMXULElement insertItemAt (in long aIndex, in DOMString aLabel, in DOMString aValue); */
NS_IMETHODIMP nsDOMXULContainerElement::InsertItemAt(PRInt32 aIndex, const nsAString & aLabel, const nsAString & aValue, nsIDOMXULElement **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIDOMXULElement removeItemAt (in long aIndex); */
NS_IMETHODIMP nsDOMXULContainerElement::RemoveItemAt(PRInt32 aIndex, nsIDOMXULElement **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned long itemCount; */
NS_IMETHODIMP nsDOMXULContainerElement::GetItemCount(PRUint32 *aItemCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long getIndexOfItem (in nsIDOMXULElement aItem); */
NS_IMETHODIMP nsDOMXULContainerElement::GetIndexOfItem(nsIDOMXULElement *aItem, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIDOMXULElement getItemAtIndex (in long aIndex); */
NS_IMETHODIMP nsDOMXULContainerElement::GetItemAtIndex(PRInt32 aIndex, nsIDOMXULElement **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIDOMXULElement parentContainer; */
NS_IMETHODIMP nsDOMXULContainerElement::GetParentContainer(nsIDOMXULElement * *aParentContainer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMXULContainerElement_h__ */
